@@ -43,7 +43,7 @@ class Command(BaseCommand):
                 pk=db_meta["pk"],
                 config=db_config
             )
-            logging.info("Importing Database {database}")
+            logging.info(f"Importing Database {database}")
             database.clean()
             database.save()
         source_tables = os.listdir(os.path.join(pwd, "source_tables"))
@@ -57,7 +57,7 @@ class Command(BaseCommand):
                 source_table=source_meta["table"],
                 description=source_meta["description"]
             )
-            logging.info("Importing SourceTable {source}")
+            logging.info(f"Importing SourceTable {source}")
             source.clean()
             source.save()
         reflections = os.listdir(os.path.join(pwd, "reflections"))
@@ -97,6 +97,6 @@ class Command(BaseCommand):
                 destination_fields=destination_fields,
                 reflection_statment=reflection_statment
             )
-            logging.info("Importing Reflection {reflection}")
+            logging.info(f"Importing Reflection {reflection}")
             reflection.clean()
             reflection.save()
